SystemOrganization addCategory: #FuelPackageLoaderTests!

FLSerializationTest subclass: #FLPackageLoaderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelPackageLoaderTests'!

!FLPackageLoaderTest classSide methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 5/16/2012 20:28'!
closureExampleForPreMaterializationAction
	^ [ Transcript show: 'aaa' ]! !

!FLPackageLoaderTest classSide methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 10/31/2011 12:00'!
packageNamesUnderTest
	^ #('FuelPackageLoader')! !

!FLPackageLoaderTest methodsFor: 'running' stamp: 'MartinDias 9/24/2011 11:37'!
categoryForMethodExtensions
	"Answers the category in which tests should add method extensions."
	
	^self stubPackageInfo methodCategoryPrefix! !

!FLPackageLoaderTest methodsFor: 'running' stamp: 'MartinDias 5/15/2012 11:08'!
expectedFailures 
	^super expectedFailures, #(testMethodWithUndeclaredGlobal)! !

!FLPackageLoaderTest methodsFor: 'running' stamp: 'MarianoMartinezPeck 5/16/2012 20:12'!
storeRemoveAndLoadPackage: aFLPackage
	| loadedPackage |

	self streamFactory writeStreamDo: [:aStream |
		FLPackageStore new storePackage: aFLPackage on: aStream ].

	"Traits are not correctly cleaned with the classFactory. Therefore, we do the full #tearDown"
	self tearDown.
	self stubPackageInfo extensionMethods do: [ :method | method methodClass removeSelectorSilently: method selector ].
	self assert: self stubPackageInfo classes isEmpty.
	self assert: self stubPackageInfo extensionMethods isEmpty.

	self streamFactory readStreamDo: [:aStream |
		SystemChangeNotifier uniqueInstance doSilently: [
			loadedPackage := FLPackageLoader new loadFrom: aStream.
		].
		classFactory createdClasses: loadedPackage behaviors ].
	
	^ loadedPackage
	! !

!FLPackageLoaderTest methodsFor: 'running' stamp: 'MarianoMartinezPeck 5/15/2012 18:54'!
storeRemoveAndLoadStubPackage
	self storeRemoveAndLoadPackage: ( FLPackage named: classFactory packageName)! !

!FLPackageLoaderTest methodsFor: 'running' stamp: 'MarianoMartinezPeck 1/24/2012 20:38'!
stubPackageInfo
	^ PackageInfo new packageName: classFactory packageName
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 22:42'!
testAdditionalObjects
	"It should send #initialize to each class."

	| aClass name materializedClass package loadedPackage |
	aClass := self newClass.
	
	package := FLPackage named: classFactory packageName.
	package at: #test putAdditionalObject: 'test'.
	package at: 42 putAdditionalObject: 68.
	
	loadedPackage := self storeRemoveAndLoadPackage: package. 

	self assert: (loadedPackage additionalObjectAt: #test) equals: 'test'.
	self assert: (loadedPackage additionalObjectAt: 42) equals: 68.
	! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:07'!
testClassInitializationFalseByDefault
	"It should send #initialize to each class."

	| aClass name materializedClass |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class 
		duringTestCompileSilently: 'initialize  ClassVariable := 1';
		duringTestCompileSilently: 'isInitialized  ^ClassVariable isNil not'.

	FLPackage mustInitializeByDefault: false.
	
	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.
	self deny: materializedClass isInitialized.
	! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:14'!
testClassInitializationFalseForThisPackage
	"It should send #initialize to each class."

	| aClass name materializedClass package |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class 
		duringTestCompileSilently: 'initialize  ClassVariable := 1';
		duringTestCompileSilently: 'isInitialized  ^ClassVariable isNil not'.

	name := aClass name.
	FLPackage mustInitializeByDefault: true.
	package := FLPackage named: classFactory packageName.
	package mustInitialize: false.
	self storeRemoveAndLoadPackage: package. 

	
	materializedClass := Smalltalk at: name.
	self deny: materializedClass isInitialized.
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:07'!
testClassInitializationTrueByDefault
	"It should send #initialize to each class."

	| aClass name materializedClass |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class 
		duringTestCompileSilently: 'initialize  ClassVariable := 1';
		duringTestCompileSilently: 'isInitialized  ^ClassVariable isNil not'.

	FLPackage mustInitializeByDefault: true.
	
	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.
	self assert: materializedClass isInitialized.
	! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:13'!
testClassInitializationTrueForThisPackage
	"It should send #initialize to each class."

	| aClass name materializedClass package |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class 
		duringTestCompileSilently: 'initialize  ClassVariable := 1';
		duringTestCompileSilently: 'isInitialized  ^ClassVariable isNil not'.

	name := aClass name.
	FLPackage mustInitializeByDefault: false.
	package := FLPackage named: classFactory packageName.
	package mustInitialize: true.
	self storeRemoveAndLoadPackage: package. 

	
	materializedClass := Smalltalk at: name.
	self assert: materializedClass isInitialized.
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:17'!
testClassRegistration
	"The class should be included in Smalltalk system dictionary."

	| aClass name materializedClass |
	"In this case we need that the class creation sends notification because of the last asssert."
	aClass := self withNotificationsNewClass.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.

	materializedClass := 
		Smalltalk 
			at: name 
			ifAbsent: [ self signalFailure: 'The class should be included in Smalltalk system dictionary.' ].
			
	self assert: classFactory defaultCategory equals: (Smalltalk organization categoryOfElement: materializedClass name).
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testExternalSuperclass
	"Tests consistency of classes' superclass."

	| aClass name materializedClass |
	aClass := self newClass.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass superclass == aClass superclass.
	self assert: (materializedClass superclass subclasses identityIncludes: materializedClass).! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreClassSideVariable
	"It should not serialize class side variable values."

	| aClass name materializedClass |
	aClass := self newClass.
	aClass class
		addInstVarNamed: 'classSideVariable';  
		duringTestCompileSilently: 'initializeClassSideVariable  classSideVariable := 1';
		duringTestCompileSilently: 'classSideVariable  ^classSideVariable'.
	aClass initializeClassSideVariable.
	self deny: aClass classSideVariable isNil.
	
	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass classSideVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:02'!
testIgnoreClassSideVariableAndDifferentPackages
	"It should not serialize class side variable values."

	| aClass name materializedClass anotherClass |
	aClass := self newClass.
	anotherClass := classFactory silentlyNewSubclassOf: Object instanceVariableNames: '' classVariableNames:  '' package: 'AnotherPackage'. 
	aClass addClassVarNamed: 'ClassSideVariable'.
	aClass class
		duringTestCompileSilently: ' classSideVariable: something ClassSideVariable := something';
		duringTestCompileSilently: 'classSideVariable  ^ ClassSideVariable'.
	aClass perform: #classSideVariable: with: anotherClass new.
	self deny: aClass classSideVariable isNil.

	name := aClass name.
	
	"We don't send storeRemoveAndLoadStubPackage because we need to remove anotherClass in the middle"
	self streamFactory writeStreamDo: [:aStream |
		FLPackageStore new storePackageNamed: classFactory packageName on: aStream ].

	"Traits are not correctly cleaned with the classFactory. Therefore, we do the full #tearDown"
	self tearDown.
	self stubPackageInfo extensionMethods do: [ :method | method methodClass removeSelectorSilently: method selector ].
	self assert: self stubPackageInfo classes isEmpty.
	self assert: self stubPackageInfo extensionMethods isEmpty.
	
	anotherClass removeFromSystem: false.

	self streamFactory readStreamDo: [:aStream |
		| package |
		SystemChangeNotifier uniqueInstance doSilently: [
			package := FLPackageLoader new loadFrom: aStream.
		].
		classFactory createdClasses: package behaviors ].
	
	
	materializedClass := Smalltalk at: name.
	
	self assert: materializedClass classSideVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreClassVariableWithClassSideMethod
	"It should not serialize class variable values."

	| aClass name materializedClass |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class
		duringTestCompileSilently: 'initializeClassVariable  ClassVariable := 1';
		duringTestCompileSilently: 'classVariable  ^ClassVariable'.
	aClass initializeClassVariable.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass classVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreClassVariableWithInstanceSideMethod
	"It should not serialize class variable values."

	| aClass name materializedClass |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass
		duringTestCompileSilently: 'initializeClassVariable  ClassVariable := 1';
		duringTestCompileSilently: 'classVariable  ^ClassVariable'.
	aClass new initializeClassVariable.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass new classVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreForeignClassSideMethod
	"It should not serialize class foreign protocol."

	| aClass name materializedClass |
	aClass := self newClass.
	aClass class
		duringTestCompileSilently: 'foreign' classified: '*foreigns';
		duringTestCompileSilently: 'core' classified: 'cores'.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: #(core) asSet equals: materializedClass class localSelectors.	
	self assert: (materializedClass class includesSelector: #core).
	self deny: (materializedClass class includesSelector: #foreign).
	self assert: #(cores) equals: materializedClass class organization categories.
	self assert: #(core) equals: materializedClass class organization allMethodSelectors.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreForeignInstanceSideMethod
	"It should not serialize class foreign protocol."

	| aClass name materializedClass |
	aClass := self newClass.
	aClass
		duringTestCompileSilently: 'foreign' classified: '*foreigns';
		duringTestCompileSilently: 'core' classified: 'cores'.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: #(core) asSet equals: materializedClass localSelectors.	
	self assert: (materializedClass includesSelector: #core).
	self deny: (materializedClass includesSelector: #foreign).
	self assert: #(cores) equals: materializedClass organization categories.
	self assert: #(core) equals: materializedClass organization allMethodSelectors.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:31'!
testIgnoreSuperClassSideVariable
	"It should not serialize class side variable values even if they come from super."

	| aSuperclass aClass name materializedClass |
	aSuperclass := self newClass.
	aClass := self newSubclassOf: aSuperclass instanceVariableNames: '' classVariableNames: ''.
	
	aSuperclass class
		addInstVarNamed: 'classSideVariable'.
	aClass class
		duringTestCompileSilently: 'initializeClassSideVariable  classSideVariable := 1';
		duringTestCompileSilently: 'classSideVariable  ^classSideVariable'.
		
	aClass initializeClassSideVariable.
	self deny: aClass classSideVariable isNil.
	
	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass classSideVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreSuperClassVariableWithClassSideMethod
	"It should not serialize class variable values even if it comes from super."

	| aSuperclass aClass name materializedClass |
	aSuperclass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass := self newSubclassOf: aSuperclass instanceVariableNames: '' classVariableNames: ''.

	aClass class
		duringTestCompileSilently: 'initializeClassVariable  ClassVariable := 1';
		duringTestCompileSilently: 'classVariable  ^ClassVariable'.
	aClass initializeClassVariable.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass classVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:26'!
testIgnoreSuperClassVariableWithInstanceSideMethod
	"It should not serialize class variable values."

	| aSuperclass aClass name materializedClass |
	aSuperclass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass := self newSubclassOf: aSuperclass instanceVariableNames: '' classVariableNames: ''.
	aClass
		duringTestCompileSilently: 'initializeClassVariable  ClassVariable := 1';
		duringTestCompileSilently: 'classVariable  ^ClassVariable'.
	aClass new initializeClassVariable.

	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: materializedClass new classVariable isNil.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:27'!
testInternalSuperclass
	"Tests consistency of classes' superclass."

	| aClass aSuperclass className superclassName materializedClass materializedSuperclass |
	aSuperclass := self newClass.
	aClass := self newSubclassOf: aSuperclass instanceVariableNames: '' classVariableNames: ''.

	superclassName := aSuperclass name.
	className := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedSuperclass := Smalltalk at: superclassName.
	materializedClass := Smalltalk at: className.

	self assert: materializedClass superclass == materializedSuperclass.
	self assert: (materializedClass superclass subclasses includes: materializedClass).
	self assert: materializedSuperclass subclasses = (Array with: materializedClass).! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:12'!
testMethodWithUndeclaredGlobal

	| name materializedClass aClass |
	Smalltalk globals removeKey: #FLGlobalVariableForTesting ifAbsent: [].
	aClass := self newClass.
	aClass class duringTestCompileSilently: 'foo  ^ FLGlobalVariableForTesting'.
	
	name := aClass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.

	self assert: (materializedClass class >> #foo valueWithReceiver: aClass arguments: #()) isNil.
	Smalltalk globals at: #FLGlobalVariableForTesting put: 42.
	self assert: (materializedClass class >> #foo valueWithReceiver: aClass arguments: #()) = 42.
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:02'!
testOriginalClassSideMethodsAreNotBroken
	"It should not serialize class variable values."

	| aClass name materializedClass |
	aClass := self newClass.
	aClass class
		duringTestCompileSilently: 'foreign' classified: '*foreigns';
		duringTestCompileSilently: 'core' classified: 'cores'.

	name := aClass name.
	self assert: (aClass class >> #foreign) category equals: #'*foreigns'.

	self streamFactory writeStreamDo: [:aStream |
		FLPackageStore new storePackageNamed: classFactory packageName on: aStream ].

	self assert: (aClass class >> #foreign) category equals: #'*foreigns'.

	"Traits are not correctly cleaned with the classFactory. Therefore, we do the full #tearDown"
	self tearDown.
	self stubPackageInfo extensionMethods do: [ :method | method methodClass removeSelectorSilently: method selector ].
	
	! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 19:03'!
testOriginalInstanceSideMethodsAreNotBroken
	"It should not serialize class variable values."

	| aClass name materializedClass |
	aClass := self newClass.
	aClass 
		duringTestCompileSilently: 'foreign' classified: '*foreigns';
		duringTestCompileSilently: 'core' classified: 'cores'.

	name := aClass name.
	self assert: (aClass >> #foreign) category equals: #'*foreigns'.

	self streamFactory writeStreamDo: [:aStream |
		FLPackageStore new storePackageNamed: classFactory packageName on: aStream ].

	self assert: (aClass >> #foreign) category equals: #'*foreigns'.

	"Traits are not correctly cleaned with the classFactory. Therefore, we do the full #tearDown"
	self tearDown.
	self stubPackageInfo extensionMethods do: [ :method | method methodClass removeSelectorSilently: method selector ].
	
	! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/16/2012 20:29'!
testPackageHeaderWithPreMaterializationActions
	"It should send #initialize to each class."

	| aClass name materializedClass package anotherClass |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class
		duringTestCompileSilently: 'classVariable: x ClassVariable := x';
		duringTestCompileSilently: 'classVariable  ^ClassVariable '.

	name := aClass name.
	package := FLPackage named: classFactory packageName.
	aClass perform: #classVariable: with: 42.
	package packageHeader addPreMaterializationAction:  self class closureExampleForPreMaterializationAction .
	self storeRemoveAndLoadPackage: package. 
	"self assert: ((Smalltalk at: #name) perform: #classVariable) equals: 43."! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/16/2012 20:13'!
testPackageWithMethodExtension
	"It should serialize package's extension methods."

	| classWithExtension categoryForMethodExtension |
	categoryForMethodExtension := self categoryForMethodExtensions.
	classWithExtension := FLPackageLoaderDummy.
	classWithExtension duringTestCompileSilently: 'fortyTwo ^42' classified: categoryForMethodExtension. 
	
	self storeRemoveAndLoadStubPackage.
	
	self assert: (classWithExtension includesSelector: #fortyTwo).
	self assert: categoryForMethodExtension equals: (classWithExtension whichCategoryIncludesSelector: #fortyTwo).
	self assert: (PackageOrganizer default packageNames includes: classFactory packageName)! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 12:48'!
testPackageWithMethodExtensionWithClassSideVariable
	"Tests that the extension method is corretly rebinded on load."

	| categoryForMethodExtension |
	categoryForMethodExtension := self categoryForMethodExtensions.
	FLPackageLoaderDummy class 
		duringTestCompileSilently: 'initializeFortyTwo  classInstanceVariable := 42' 
		classified: categoryForMethodExtension. 
	FLPackageLoaderDummy classInstanceVariable: nil.

	self storeRemoveAndLoadStubPackage.

	"Bindings in the class method should be recalculated on load."	
	self shouldnt: [ FLPackageLoaderDummy initializeFortyTwo ] raise: Error.
	self assert: 42 equals: FLPackageLoaderDummy classInstanceVariable.

! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 12:21'!
testPackageWithMethodExtensionWithClassVariable
	"Tests that the extension method is corretly rebinded on load."

	| categoryForMethodExtension |
	categoryForMethodExtension := self categoryForMethodExtensions.
	FLPackageLoaderDummy class 
		duringTestCompileSilently: 'initializeFortyTwo  ClassVariable := 42' 
		classified: categoryForMethodExtension. 

	"After next lines, the class method points to an old binding. (This is not the ideal way of testing because it is breaking consistency of the class.)"
	FLPackageLoaderDummy classPool removeKey: #ClassVariable.
	FLPackageLoaderDummy classPool at: #ClassVariable put: nil.

	self storeRemoveAndLoadStubPackage.

	"Bindings in the class method should be recalculated on load."	
	self shouldnt: [ FLPackageLoaderDummy initializeFortyTwo ] raise: Error.
	self assert: 42 equals: (FLPackageLoaderDummy classPool at: #ClassVariable).

! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:29'!
testPackageWithTwoCategories
	"It should serialize multiple categories by package."

	| aStream classNames |
	self newClassInCategory: 'One'.
	self newClassInCategory: 'Two'.
	classNames := classFactory createdClassNames.

	self storeRemoveAndLoadStubPackage.
	
	self assert: (PackageOrganizer default packageNames includes: classFactory packageName) description: 'The package should be present in PackageOrganizer default.'.! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 23:41'!
testPostLoadActions
	"It should send #initialize to each class."

	| aClass name materializedClass package |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable ClassVariable2'.
	aClass class
		duringTestCompileSilently: 'postLoadMethod: classes  ClassVariable := classes';
		duringTestCompileSilently: 'postLoadMethod2  ClassVariable2 := 1';
		duringTestCompileSilently: 'classVariable  ^ClassVariable ';	
		duringTestCompileSilently: 'classVariable2  ^ClassVariable2 '.
				

	name := aClass name.
	FLPackage mustInitializeByDefault: false.
	package := FLPackage named: classFactory packageName.
	"I cannot use 'name' because since it is a instance variable, the closure won't be clean' "
	package addPostLoadAction: [:aPackage | (Smalltalk at: #ClassForTestToBeDeleted1) perform: #postLoadMethod: with: aPackage classes ].
	package addPostLoadAction: [ (Smalltalk at: #ClassForTestToBeDeleted1) perform: #postLoadMethod2].
	
	self storeRemoveAndLoadPackage: package. 

	materializedClass := Smalltalk at: name.
	self assert: (materializedClass perform:  #classVariable) first name equals: #ClassForTestToBeDeleted1.
	self assert: (materializedClass perform:  #classVariable2)  equals: 1.
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 5/15/2012 21:19'!
testPostLoadActionsWithNonCleanClosure
	"It should send #initialize to each class."

	| aClass name materializedClass package |
	aClass := self newSubclassOf: Object instanceVariableNames: '' classVariableNames: 'ClassVariable'.
	aClass class
		duringTestCompileSilently: 'postLoadMethod: classes  ClassVariable := classes';
		duringTestCompileSilently: 'classVariable  ^ClassVariable '.

	name := aClass name.
	FLPackage mustInitializeByDefault: false.
	package := FLPackage named: classFactory packageName.
	"Since 'name' is a instance variable, the closure won't be clean "
	self should: [package addPostLoadAction: [:aPackage | name ]] raise: Error.
! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:29'!
testSubclassesRegistration
	"Tests consistency of classes' superclass."

	| aClass name materializedClass aSubclass subclassName materializeSubclass |
	aClass := self newClass.
	aSubclass := self newSubclassOf: aClass instanceVariableNames: '' classVariableNames:  ''. 

	name := aClass name.
	subclassName := aSubclass name.
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.
	materializeSubclass := Smalltalk at: subclassName.

	self assert: materializedClass superclass == aClass superclass.
	self assert: (materializedClass superclass subclasses identityIncludes: materializedClass).
	self assert: (materializeSubclass superclass == materializedClass).
	self assert: (materializedClass subclasses identityIncludes: materializeSubclass).
	! !

!FLPackageLoaderTest methodsFor: 'tests' stamp: 'MarianoMartinezPeck 4/19/2012 19:29'!
testTraitLoad
	"Tests that traits are correctly reinserted in the system."

	| aClass name materializedClass  materializedTrait aTrait traitName |
	aClass := self newClass.
	aTrait := self newTraitSuffixed: 'aTrait'.
	name := aClass name.
	aTrait duringTestCompileSilently: 'instanceBindings  Object name. ', name , '  name.'.
	aClass addToComposition: aTrait.
	traitName := aTrait name.
	
	self storeRemoveAndLoadStubPackage.
	materializedClass := Smalltalk at: name.
	materializedTrait := Smalltalk at: traitName.

	self assert: (materializedClass traitComposition includesTrait: materializedTrait).
	self assert: ((materializedTrait >> #instanceBindings) literalAt: 2) == (Smalltalk globals associationAt: #Object).
	self assert: ((materializedTrait >> #instanceBindings) literalAt: 3) == (Smalltalk globals associationAt: name).
	! !

Object subclass: #FLPackageLoaderDummy
	instanceVariableNames: ''
	classVariableNames: 'ClassVariable'
	poolDictionaries: ''
	category: 'FuelPackageLoaderTests'!

FLPackageLoaderDummy class
	instanceVariableNames: 'classInstanceVariable'!

FLPackageLoaderDummy class
	instanceVariableNames: 'classInstanceVariable'!

!FLPackageLoaderDummy classSide methodsFor: 'accessing' stamp: 'MartinDias 9/24/2011 11:38'!
classInstanceVariable
	^ classInstanceVariable! !

!FLPackageLoaderDummy classSide methodsFor: 'accessing' stamp: 'MartinDias 9/24/2011 11:38'!
classInstanceVariable: anObject
	classInstanceVariable := anObject! !
